import pytest
from .. import src
import os

l = None
def setup_module(module):
    global l
    l = src.my_logger(name='test.log',level=10)

def test_file_creation():
    l.debug('Test file creation')
    assert os.path.exists('test.log')

def test_correct_level():
    l = src.my_logger(name='test.log')
    test_msg = 'TEST'
    l.debug(test_msg)
    with open('test.log','r') as f:
        last_record = f.read().split('\n')[-2] #The last item is an empty string
        msg = last_record.split(' - ')[-1]
    assert test_msg == msg


import pytest
from .. import src
import os
import pymssql
from sqlalchemy.pool import NullPool
import mariadb

def test_mssql_db_error():
    with pytest.raises(pymssql._pymssql.OperationalError):
        db = src.MsSQLDatabase(
            server = os.getenv('DB_mssql_SERVER'),
            port=os.getenv('DB_mssql_PORT'),
            user = os.getenv('DB_mssql_USER_ERROR'),
            password = os.getenv('DB_mssql_PASSWORD_ERROR'),
            database = os.getenv('DB_mssql_DATABASE'))
        with db as conn:
            res = conn.execute('SELECT * FROM DockerTest.dbo.Person')

def test_maria_db_error():
    with pytest.raises(mariadb.Error):
        db = src.MariaDatabase(
            server = os.getenv('DB_mariadb_SERVER'),
            user = os.getenv('DB_mariadb_USER_ERROR'),
            password = os.getenv('DB_mariadb_PASSWORD_ERROR'),
            database = os.getenv('DB_mariadb_DATABASE'))
        with db as conn:
            res = conn.execute('SELECT * FROM DockerTest.dbo.Person')
            
def test_mssql_db_success():
    db = src.MsSQLDatabase(
            server = os.getenv('DB_mssql_SERVER'),
            user = os.getenv('DB_mssql_USER'),
            password = os.getenv('DB_mssql_PASSWORD'),
            database = os.getenv('DB_mssql_DATABASE'),
            pool_size=NullPool)
    assert db.connected


def test_maria_db_success():
    db = src.MariaDatabase(
            server = os.getenv('DB_mariadb_SERVER'),
            user = os.getenv('DB_mariadb_USER'),
            password = os.getenv('DB_mariadb_PASSWORD'),
            database = os.getenv('DB_mariadb_DATABASE'),
            pool_size=NullPool)
    assert db.connected


from setuptools import find_packages, setup

with open("./mario_utils/README.md", 'r') as f:
    long_description = f.read()

setup(
    name="marioutils",
    version="0.0.2",
    description="Utils library for DB connection and logging",
    packages=find_packages(),
    package_data={'mario_utils':['databasemanagement/*'],'mario_utils':['logger/*']},
    include_package_data=True,
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/MarioHdzCtu/MarioUtils",
    author="Mario Hernandez",
    author_email="mariohertu@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent"
    ],
    install_requires=[
        "pymssql >= 2.2.11",
        "sqlalchemy >= 2.0.25",
        "mariadb >= 1.1.10"
    ],
    extras_require={
        "dev": ["pytest>=8.0.0", "twine >=4.0.2"]
    },
    python_requires=">=3.10.12",
    include_dirs=True
)